Enum rustc_mir::transform::promote_consts::Candidate
[−]
[src]
pub enum Candidate {
Ref(Location),
ShuffleIndices(BasicBlock),
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
A "root candidate" for promotion, which will become the returned value in a promoted MIR, unless it's a subset of a larger candidate.
Variants
Ref(Location)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Borrow of a constant temporary.
ShuffleIndices(BasicBlock)🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Array of indices found in the third argument of a call to one of the simd_shuffleN intrinsics.